OccupiedEntry

Struct OccupiedEntry 

pub struct OccupiedEntry<'a, T> { /* private fields */ }
A view into a single occupied location in a HeaderMap.

This struct is returned as part of the Entry enum.

Implementations

Source

impl<'a, T> OccupiedEntry<'a, T>

pub fn key(&self) -> &HeaderName

Returns a reference to the entry’s key.

Examples
let mut map = HeaderMap::new();
map.insert(HOST, "world".parse().unwrap());

if let Entry::Occupied(e) = map.entry("host") {
    assert_eq!("host", e.key());
}
pub fn get(&self) -> &T

Get a reference to the first value in the entry.

Values are stored in insertion order.

Panics

get panics if there are no values associated with the entry.

Examples
let mut map = HeaderMap::new();
map.insert(HOST, "hello.world".parse().unwrap());

if let Entry::Occupied(mut e) = map.entry("host") {
    assert_eq!(e.get(), &"hello.world");

    e.append("hello.earth".parse().unwrap());

    assert_eq!(e.get(), &"hello.world");
}
pub fn get_mut(&mut self) -> &mut T

Get a mutable reference to the first value in the entry.

Values are stored in insertion order.

Panics

get_mut panics if there are no values associated with the entry.

Examples
let mut map = HeaderMap::default();
map.insert(HOST, "hello.world".to_string());

if let Entry::Occupied(mut e) = map.entry("host") {
    e.get_mut().push_str("-2");
    assert_eq!(e.get(), &"hello.world-2");
}
pub fn into_mut(self) -> &'a mut T

Converts the OccupiedEntry into a mutable reference to the first value.

The lifetime of the returned reference is bound to the original map.

Panics

into_mut panics if there are no values associated with the entry.

Examples
let mut map = HeaderMap::default();
map.insert(HOST, "hello.world".to_string());
map.append(HOST, "hello.earth".to_string());

if let Entry::Occupied(e) = map.entry("host") {
    e.into_mut().push_str("-2");
}

assert_eq!("hello.world-2", map["host"]);
pub fn insert(&mut self, value: T) -> T

Sets the value of the entry.

All previous values associated with the entry are removed and the first one is returned. See insert_mult for an API that returns all values.

Examples
let mut map = HeaderMap::new();
map.insert(HOST, "hello.world".parse().unwrap());

if let Entry::Occupied(mut e) = map.entry("host") {
    let mut prev = e.insert("earth".parse().unwrap());
    assert_eq!("hello.world", prev);
}

assert_eq!("earth", map["host"]);
pub fn insert_mult(&mut self, value: T) -> ValueDrain<'_, T>

Sets the value of the entry.

This function does the same as insert except it returns an iterator that yields all values previously associated with the key.

Examples
let mut map = HeaderMap::new();
map.insert(HOST, "world".parse().unwrap());
map.append(HOST, "world2".parse().unwrap());

if let Entry::Occupied(mut e) = map.entry("host") {
    let mut prev = e.insert_mult("earth".parse().unwrap());
    assert_eq!("world", prev.next().unwrap());
    assert_eq!("world2", prev.next().unwrap());
    assert!(prev.next().is_none());
}

assert_eq!("earth", map["host"]);
pub fn append(&mut self, value: T)

Insert the value into the entry.

The new value is appended to the end of the entry’s value list. All previous values associated with the entry are retained.

Examples
let mut map = HeaderMap::new();
map.insert(HOST, "world".parse().unwrap());

if let Entry::Occupied(mut e) = map.entry("host") {
    e.append("earth".parse().unwrap());
}

let values = map.get_all("host");
let mut i = values.iter();
assert_eq!("world", *i.next().unwrap());
assert_eq!("earth", *i.next().unwrap());
pub fn remove(self) -> T

Remove the entry from the map.

All values associated with the entry are removed and the first one is returned. See remove_entry_mult for an API that returns all values.

Examples
let mut map = HeaderMap::new();
map.insert(HOST, "world".parse().unwrap());

if let Entry::Occupied(e) = map.entry("host") {
    let mut prev = e.remove();
    assert_eq!("world", prev);
}

assert!(!map.contains_key("host"));
pub fn remove_entry(self) -> (HeaderName, T)

Remove the entry from the map.

The key and all values associated with the entry are removed and the first one is returned. See remove_entry_mult for an API that returns all values.

Examples
let mut map = HeaderMap::new();
map.insert(HOST, "world".parse().unwrap());

if let Entry::Occupied(e) = map.entry("host") {
    let (key, mut prev) = e.remove_entry();
    assert_eq!("host", key.as_str());
    assert_eq!("world", prev);
}

assert!(!map.contains_key("host"));
pub fn remove_entry_mult(self) -> (HeaderName, ValueDrain<'a, T>)

Remove the entry from the map.

The key and all values associated with the entry are removed and returned.

pub fn iter(&self) -> ValueIter<'_, T>

Returns an iterator visiting all values associated with the entry.

Values are iterated in insertion order.

Examples
let mut map = HeaderMap::new();
map.insert(HOST, "world".parse().unwrap());
map.append(HOST, "earth".parse().unwrap());

if let Entry::Occupied(e) = map.entry("host") {
    let mut iter = e.iter();
    assert_eq!(&"world", iter.next().unwrap());
    assert_eq!(&"earth", iter.next().unwrap());
    assert!(iter.next().is_none());
}
pub fn iter_mut(&mut self) -> ValueIterMut<'_, T>

Returns an iterator mutably visiting all values associated with the entry.

Values are iterated in insertion order.

Examples
let mut map = HeaderMap::default();
map.insert(HOST, "world".to_string());
map.append(HOST, "earth".to_string());

if let Entry::Occupied(mut e) = map.entry("host") {
    for e in e.iter_mut() {
        e.push_str("-boop");
    }
}

let mut values = map.get_all("host");
let mut i = values.iter();
assert_eq!(&"world-boop", i.next().unwrap());
assert_eq!(&"earth-boop", i.next().unwrap());