pub struct MethodRouter<S> { /* private fields */ }Expand description
Router that dispatches requests to different handlers based on the HTTP method.
Implementations
Sourceimpl<S> MethodRouter<S>
impl<S> MethodRouter<S>
Sourcepub fn get<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn get<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP GET requests.
Sourcepub fn post<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn post<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP POST requests.
Sourcepub fn put<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn put<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP PUT requests.
Sourcepub fn delete<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn delete<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP DELETE requests.
Sourcepub fn options<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn options<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP OPTIONS requests.
Sourcepub fn head<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn head<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP HEAD requests.
Sourcepub fn patch<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn patch<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP PATCH requests.
Sourcepub fn trace<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn trace<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP TRACE requests.
Sourcepub fn connect<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
pub fn connect<H, T>(self, handler: H) -> Selfwhere
H: Handler<T, S>,
T: 'static,
Add a handler for HTTP CONNECT requests.
Sourcepub fn hoop<F, Fut, Res>(self, middleware: F) -> Self
pub fn hoop<F, Fut, Res>(self, middleware: F) -> Self
Apply a middleware handler to all endpoints registered in this MethodRouter.
Middleware takes a Request and a Next<S> continuation.
Sourcepub fn hoop_at<F, Fut, Res>(
self,
position: MiddlewarePosition,
middleware: F,
) -> Self
pub fn hoop_at<F, Fut, Res>( self, position: MiddlewarePosition, middleware: F, ) -> Self
Apply a middleware handler to all endpoints registered in this MethodRouter at a specific position (First/Last).
Sourcepub fn compile_in_place(&mut self)
pub fn compile_in_place(&mut self)
Compile all handler middleware chains in-place.
Sourcepub fn with_state<S2>(self, state: &Arc<S>) -> MethodRouter<S2>
pub fn with_state<S2>(self, state: &Arc<S>) -> MethodRouter<S2>
Capture a state and transition this method router to another state type.