CloseCode

Enum CloseCode 

pub enum CloseCode {
Show 13 variants Normal, Away, Protocol, Unsupported, Status, Abnormal, Invalid, Policy, Size, Extension, Error, Restart, Again, // some variants omitted
}
Status code used to indicate why an endpoint is closing the WebSocket connection.

Variants



Normal

Indicates a normal closure, meaning that the purpose for which the connection was established has been fulfilled.



Away

Indicates that an endpoint is “going away”, such as a server going down or a browser having navigated away from a page.



Protocol

Indicates that an endpoint is terminating the connection due to a protocol error.



Unsupported

Indicates that an endpoint is terminating the connection because it has received a type of data it cannot accept (e.g., an endpoint that understands only text data MAY send this if it receives a binary message).



Status

Indicates that no status code was included in a closing frame. This close code makes it possible to use a single method, on_close to handle even cases where no close code was provided.



Abnormal

Indicates an abnormal closure. If the abnormal closure was due to an error, this close code will not be used. Instead, the on_error method of the handler will be called with the error. However, if the connection is simply dropped, without an error, this close code will be sent to the handler.



Invalid

Indicates that an endpoint is terminating the connection because it has received data within a message that was not consistent with the type of the message (e.g., non-UTF-8 [RFC3629] data within a text message).



Policy

Indicates that an endpoint is terminating the connection because it has received a message that violates its policy. This is a generic status code that can be returned when there is no other more suitable status code (e.g., Unsupported or Size) or if there is a need to hide specific details about the policy.



Size

Indicates that an endpoint is terminating the connection because it has received a message that is too big for it to process.



Extension

Indicates that an endpoint (client) is terminating the connection because it has expected the server to negotiate one or more extension, but the server didn’t return them in the response message of the WebSocket handshake. The list of extensions that are needed should be given as the reason for closing. Note that this status code is not used by the server, because it can fail the WebSocket handshake instead.



Error

Indicates that a server is terminating the connection because it encountered an unexpected condition that prevented it from fulfilling the request.



Restart

Indicates that the server is restarting. A client may choose to reconnect, and if it does, it should use a randomized delay of 5-30 seconds between attempts.



Again

Indicates that the server is overloaded and the client should either connect to a different IP (when multiple targets exist), or reconnect to the same IP when a user has performed an action.

Implementations

Source

impl CloseCode

pub fn is_allowed(self) -> bool

Check if this CloseCode is allowed.