Response utilities and the IntoResponse trait.
Re-exports
Modules
- sse
- Server-Sent Events (SSE) — see the module docs for usage. Requires the
ssefeature. Server-Sent Events (SSE), mirroringaxum::response::sse.
Structs
- Append
Headers - Appends an arbitrary collection of headers to a response without
replacing any existing header of the same name, matching
axum::response::AppendHeaders. - Html
- An HTML response.
- Redirect
- Response that redirects the client to another location.
- Response
Parts - The response under construction, passed to
IntoResponseParts::into_response_partsso implementors can attach headers/extensions without unpacking the whole response.
Enums
- Body
- The unified body type for Tachyon-Web responses.
Traits
- Into
Response - Trait for generating an HTTP response.
- Into
Response Parts - Trait for types that attach headers/extensions to a response without providing its body — the building block for flexible, order-independent response tuples.